CCL: Globals

CCL

Here is a list of all functions, variables, defines, enums, and typedefs with links to the files they belong to:

### - s -

- SETUP_FNAME : ctest.h
- SetupFunc : ctest.h
- SIGMA_TOLERANCE : ccl_test_massfunc.c
- SIGMAM_TOLERANCE : ccl_test_sigmaM.c
- SOLAR_MASS : ccl_constants.h
- STBOLTZ : ccl_constants.h
- STRING : ccl_core.h
- SZ_GC : ccl_sample_run.c
- SZ_SH : ccl_sample_run.c
- SZ_VAL : ccl_test_cls.c